#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%define         github_user matrix-org
%define         short_name canonicaljson
%{?sle15_python_module_pythons}
Name:           python-%{short_name}%{psuffix}
Version:        2.0.0
Release:        bp160.1.7
Summary:        Canonical JSON for Python
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/matrix-org/python-canonicaljson
Source:         https://github.com/matrix-org/python-canonicaljson/archive/v%{version}.tar.gz
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module frozendict >= 2.1.3}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module simplejson >= 3.14.0}
BuildRequires:  %{python_module typing_extensions}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-frozendict >= 1.0
Requires:       python-simplejson >= 3.14.0
Requires:       python-six
Requires:       python-typing_extensions
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module %{short_name}}
%endif
%python_subpackages

%description
This is a Python module which encodes objects and arrays into JSON as per
RFC 7159.

* Sorts object keys so that it yields the same result each time.
* Has no insignificant whitespace to make the output as small as possible.
* Escapes only the characters that must be escaped, U+0000 to U+0019 /
  U+0022 / U+0056, to keep the output as small as possible.
* Uses the shortest escape sequence for each escaped character.
* Encodes the JSON as UTF-8.
* Can encode frozendict immutable dictionaries.

%prep
%setup -q -n python-canonicaljson-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pyunittest discover -v
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/%{short_name}
%{python_sitelib}/%{short_name}-%{version}*-info
%endif

%changelog
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.0:
  * Add a generic `register_preserialisation_callback` mechanism,
    which allows users to teach canonicaljson how to JSON-encode custom
    types.
  * Remove support for serialising `frozendict` instances. Use
    the new `register_preserialisation_callback` mechanism to replace
    this functionality if needed.
  * Remove support for `simplejson` and the
    `set_json_library`alternative json libraries.
* Mon May 15 2023 Dirk Müller <dmueller@suse.com>
- remove redundant _service file
* Tue Feb 28 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.6.5
  - Use a property to define JsonLibrary by @DMRobertson in #57
* Tue Feb 21 2023 Matej Cepl <mcepl@suse.com>
- Don't switch off tests completely just skip the failing ones.
- And frozendict works on 3.11 (just slower).
* Mon Feb 20 2023 Marcus Rueckert <mrueckert@suse.de>
- disable python 3.11 until frozendict supports it
* Tue Nov 22 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.6.4
  - Remove unused setuptools_scm build requirement.
  - Properly package the canonicaljson module (#52)
- switch to pyproject build
* Wed Jun  8 2022 Marcus Rueckert <mrueckert@suse.de>
- add BR/Requires for typing_extension. new in 1.6.2
* Wed Jun  8 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.6.2
  - Add type annotations (#49).
  - 1.6.2 is a rerelease of 1.6.1 with the version numbers fixed in
    the tarball.
* Tue Jun  7 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.6.0
  - Make frozendict import conditional. by @BURG3R5 in #46
* Wed May 11 2022 Matej Cepl <mcepl@suse.com>
- Bump required version of frozendict to work with Python 3.10
  (gh#matrix-org/python-canonicaljson#45).
- Clean up SPEC.
* Fri Jan  7 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.5.0
  - Add code to handle frozendict implementations using c-extension
  - Add tests for Python 3.10
* Thu Apr 29 2021 Oliver Kurz <okurz@suse.com>
- Exclude tests on older SLE+Leap due to "ImportError: cannot import name inf"
* Tue Sep  8 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.4.0:
  - Fix producing non-standard JSON for Infinity, -Infinity, and
    NaN. This could cause errors when encoding objects into
    canonical JSON that previously used to work, but were
    incompatible with JSON implementations in other languages.
  - Use UTF-8 to fix ASCII encoding errors when data containing
    Unicode was attempted to be pretty-printed.
- Update to 1.3.0:
  - The minimum version of simplejson was bumped to 3.14.0.
  - Obsolete workaround for slow encoding of Unicode characters was
    removed.
  - New APIs were added to iteratively encode JSON.
* Thu Aug 13 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.2.0:
  - JSON from the standard library is used automatically on PyPy.
  - Support for Python versions which are end-of-lifed was dropped,
    Python >= 3.5 is supported and tested in continuous
    integration.
  - An API to configure the underlying JSON library was added
    (set_json_library).
* Thu Feb 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.4:
  * Fix error when encoding non-BMP characters on UCS-2 python builds (fixes issue #12).
- Use same syntax for test multibuild like in other pkgs
* Mon Apr 23 2018 jengelh@inai.de
- Update descriptions.
* Sun Apr 22 2018 okurz@suse.com
- Add missing runtime requirement 'python-six'
* Sun Apr 22 2018 okurz@suse.com
- Add package self-test based on multibuild
* Fri Apr 20 2018 okurz@suse.com
- Cleanup duplicate files in singlespec package with fdupes
* Fri Apr 20 2018 okurz@suse.com
- Update to 1.1.3
* Mon Feb 27 2017 okurz@suse.com
- Initial submission
